@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-"""Pyrgg main."""
+"""PyRGG main."""
 from pyrgg.graph_gen import *
 from pyrgg.functions import *
 from pyrgg.params import *
@@ -10,6 +10,7 @@ import doctest
 from art import tprint
 import pyrgg.engines.pyrgg as pyrgg_engine
 import pyrgg.engines.erdos_reyni_gilbert as erg_engine
+import pyrgg.engines.erdos_reyni as er_engine
 
 GENERATOR_MENU = {
     1: dimacs_maker,
@@ -33,6 +34,7 @@ GENERATOR_MENU = {
 ENGINE_MAPPER = {
     1: pyrgg_engine,
     2: erg_engine,
+    3: er_engine,
 }
 
 
@@ -115,7 +117,7 @@ def main():
             print("Done!")
         sys.exit(error_flag)
     else:
-        tprint("Pyrgg", "larry3d")
+        tprint("PyRGG", "larry3d")
         tprint("v" + PYRGG_VERSION)
         description_print()
         EXIT_FLAG = False
@@ -127,7 +129,7 @@ def main():
                 input_dict = check_for_config()
             run(input_dict)
             INPUTINDEX = str(
-                input("Press [R] to restart Pyrgg or any other key to exit."))
+                input("Press [R] to restart PyRGG or any other key to exit."))
             if INPUTINDEX.upper() != "R":
                 EXIT_FLAG = True
 
