@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-"""Pyrgg params."""
+"""PyRGG params."""
 from textwrap import dedent, fill
 import os
 
@@ -9,8 +9,9 @@ MENU_ITEMS = {
     1: ["engine", dedent(
         """\
         - Select generation engine :
-        1- Pyrgg engine
+        1- PyRGG
         2- Erdos-Renyi-Gilbert - G(n, p)
+        3- Erdos-Renyi - G(n, m)
         """
     )],
     2: ["file_name", "- File Name (Not Empty) : "],
@@ -61,16 +62,11 @@ SUFFIX_MENU = {
 ENGINE_MENU = {
     1: "pyrgg",
     2: "erg",
+    3: "er",
 }
 
 ENGINE_MENU_INV = {v: k for k, v in ENGINE_MENU.items()}
 
-ERG_ENGINE_PARAMS = {
-    1: ["vertices", "- Vertices Number (>=0) : "],
-    2: ["probability", "- Probability (0 <= p <= 1) : "],
-    3: ["direct", "- Undirected[0] or Directed[1]"],
-}
-
 PYRGG_ENGINE_PARAMS = {
     1: ["vertices", "- Vertices Number (>=0) : "],
     2: ["min_edge", "- Min Edge Number - Connected to Each Vertex (>=0) : "],
@@ -84,9 +80,22 @@ PYRGG_ENGINE_PARAMS = {
     10: ["multigraph", "- Simple[0] or Multigraph[1]"],
 }
 
+ERG_ENGINE_PARAMS = {
+    1: ["vertices", "- Vertices Number (>=0) : "],
+    2: ["probability", "- Probability (0 <= p <= 1) : "],
+    3: ["direct", "- Undirected[0] or Directed[1]"],
+}
+
+ER_ENGINE_PARAMS = {
+    1: ["vertices", "- Vertices Number (>=0) : "],
+    2: ["edge_number", "- Edge Number (>=0) : "],
+    3: ["direct", "- Undirected[0] or Directed[1]"],
+}
+
 ENGINE_PARAM_MAP = {
     1: PYRGG_ENGINE_PARAMS,
     2: ERG_ENGINE_PARAMS,
+    3: ER_ENGINE_PARAMS,
 }
 
 OUTPUT_FORMAT = {i: output_format[1:].upper()
@@ -95,7 +104,7 @@ OUTPUT_FORMAT = {i: output_format[1:].upper()
 OUTPUT_FORMAT_INV = {v: k for k, v in OUTPUT_FORMAT.items()}
 
 
-PYRGG_VERSION = "1.5"
+PYRGG_VERSION = "1.6"
 
 SOURCE_DIR = os.getcwd()
 
@@ -105,7 +114,7 @@ PYRGG_LINKS = """
 Webpage : https://www.pyrgg.site
 Repository : https://github.com/sepandhaghighi/pyrgg
 Paper : https://doi.org/10.21105/joss.00331
-* If you use Pyrgg in your research, please cite our paper
+* If you use PyRGG in your research, please cite our paper
 """
 
 _description = """\
